@@ -1,6 +1,8 @@
 use colored::Colorize;
 use scfmt::scfmt;
 use std::{env, path::PathBuf};
+#[macro_use]
+extern crate version;
 
 fn print_err(err: &str) {
     println!("{}: {}", "error".red().bold(), err);
@@ -41,8 +43,11 @@ OPTIONS:
     *None*                      Passing no option simply formats bracketed structured comments
     ab, add_brackets            Gives brackets to any bracketless strucutered comments
     rb, remove_brackets         Removes brackets from any bracketed structured comments
-    n,  null                    Invalidates any existing bracketed comments, while preserving their content"
+    n,  null                    Invalidates any existing bracketed comments, while preserving their content
+    v,  version                 Print current version info"
             )
+        } else if &args[1] == "version" || &args[1] == "v" {
+            println!("scfmt {}", version!());
         } else {
             let path = PathBuf::from(dir);
 
